Package: SeqSQC
Title: A bioconductor package for sample quality check with next
        generation sequencing data
Version: 1.35.0
Authors@R: person("Qian", "Liu", email = "qliu7@buffalo.edu", role = c("aut", "cre"))
Description: The SeqSQC is designed to identify problematic samples in NGS data,
    including samples with gender mismatch, contamination, cryptic relatedness, and
    population outlier.
biocViews: Experiment Data, Homo_sapiens_Data, Sequencing Data,
        Project1000genomes, Genome
Depends: R (>= 3.4), ExperimentHub (>= 1.3.7), SNPRelate (>= 1.10.2)
License: GPL-3
Encoding: UTF-8
URL: https://github.com/Liubuntu/SeqSQC
BugReports: https://github.com/Liubuntu/SeqSQC/issues
RoxygenNote: 7.3.1
VignetteBuilder: knitr
Imports: e1071, GenomicRanges, gdsfmt, ggplot2, GGally, IRanges,
        methods, plotly, RColorBrewer, reshape2, rmarkdown, S4Vectors,
        stats, utils
Suggests: BiocStyle, knitr, testthat
git_url: https://git.bioconductor.org/packages/SeqSQC
git_branch: devel
git_last_commit: d08f659
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 01:06:15 UTC; biocbuild
Author: Qian Liu [aut, cre]
Maintainer: Qian Liu <qliu7@buffalo.edu>
