# Generated by roxygen2: do not edit by hand

export(IBDCheck)
export(IBDRemove)
export(Inbreeding)
export(LoadVfile)
export(MissingRate)
export(PCACheck)
export(RenderReport)
export(SeqOpen)
export(SeqSQC)
export(SexCheck)
export(plotQC)
export(problemList)
export(sampleQC)
exportClasses(SeqSQC)
exportMethods("QCresult<-")
exportMethods("gdsfile<-")
exportMethods(QCresult)
exportMethods(gdsfile)
import(ExperimentHub)
import(GGally)
import(GenomicRanges)
import(IRanges)
import(RColorBrewer)
import(S4Vectors)
import(SNPRelate)
import(e1071)
import(gdsfmt)
import(ggplot2)
import(methods)
import(plotly)
import(reshape2)
importFrom(rmarkdown,render)
importFrom(stats,as.formula)
importFrom(stats,predict)
importFrom(utils,read.table)
importFrom(utils,write.table)
